# Normalization in mouse primary visual cortex

## **Summary**

This repository contains the datasets described in Zayyad, et. al. (2023) “Normalization in mouse primary visual cortex.” 

## Repository content and structure
The data is included in two directories: 1) optophysiology_data, which includes two-photon imaging data from awake mouse primary visual cortex, and 2) electrophysiology_data, which includes electrophysiology data from awake mouse primary visual cortex. Details about the experimental setup and stimuli presented can be found in Zayyad, et. al. (2023) “Normalization in mouse primary visual cortex.” 

## Repository Structure

### Directory optophysiology_data
This directory includes two-photon imaging datasets from awake mouse primary visual cortex. Each matlab file includes data from one recording session. 

Within the optophysiology files, neuron responses are organized as follows:

**cell_ordered:** Data collected during the presentation of the cross-orientated stimulus set. The data is organized as a 1 x n (number of neurons) struct with two fields, “grating_response” and “grey_response.” 
For each neuron, the field “grating_response” includes 20 x 25 cells, in which each row represents a repetition and each columns represents a stimulus as below, with the columns representing the contrast of the 90 degree component and the rows representing the contrast of the 180 degree component:

[

|          | 0%       | 6%       | 12%      | 25%      | 50%      |
| -------- | -------- | -------- | -------- | -------- | -------- |
| 0%       | 1        | 2        | 3        | 4        | 5        |
| -------- | -------- | -------- | -------- | -------- | -------- |
| 6%       | 6        | 7        | 8        | 9        | 10       |
| -------- | -------- | -------- | -------- | -------- | -------- |
| 12%      | 11       | 12       | 13       | 14       | 15       |
| -------- | -------- | -------- | -------- | -------- | -------- |
| 25%      | 16       | 17       | 18       | 19       | 20       | 
| -------- | -------- | -------- | -------- | -------- | -------- |
| 50%      | 21       | 22       | 23       | 24       | 25       |

]

Each cell includes [1 x sample number] dF/F of the neuron, recorded during the corresponding stimulus presentation. The number of samples recorded per stimulus presentation depends on the imaging frequency for the recording session as a whole, which depends on the number of neurons detected in the field of view imaged in a recording session (as described previously in Sadovsky et al, 2011). 

Similarly, for each neuron, the field “grey_response” includes 20 x 25 cells, in which each row represents a repetition and each columns represents a stimulus. Each cell includes the dF/F of the neuron, recorded during the grey preceding the corresponding stimulus presentation.

**cell_ordered_gratings:** As above, but for data collected during the presentation of the drifting grating stimulus set. Stimuli 1 through 8 are the drifting gratings between 0 and 315 with intervals of 45 degrees, in ascending order.

### Directory electrophysiology_data

This directory includes electrophysiology datasets from awake mouse primary visual cortex. Each matlab file includes data from one recording session.

Within the electrophysiology files, sorted unit responses are organized as follows: 

Each dataset is a struct, “d” with a field “neurons” that includes a struct of length u, where each sub-struct includes the data from one sorted unit. For a unit u0, d.neuron{1, u0}.task{1,1} includes the responses of the unit to the 25 cross-oriented stimuli of the plaid stimulus set. The 25 cross-oriented stimuli are numbered as above.

Similarly, d.neuron{1, u0}.task{1,2} includes the responses of unit u0 to the drifting grating stimuli. Stimuli 1 through 12 are the drifting gratings between 0 and 330 with intervals of 30 degrees, in ascending order.

## Accessing and using the data 

### Downloading the data 

Use gin to download the data or download the latest release by clicking on the file names in each repository folder. 

